0.9.9 API documentation: GLM_EXT_vector_int1

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Typedefs
GLM_EXT_vector_int1
Stable extensions

Exposes ivec1 vector type. More...

## Typedefs
typedef vec< 1, int, defaultp > | ivec1
| 1 component vector of signed integer numbers.

## Detailed Description

Exposes ivec1 vector type.

Include <glm/ext/vector_int1.hpp> to use the features of this extension.

See also
  GLM_EXT_vector_uint1 extension.
  GLM_EXT_vector_int1_precision extension.